function z=Errors4SS(guess,ExogPrices)
global Parameters;
%Steady state conditions, ExogPrices are interest and wage rates

R=ExogPrices.R;
theta=Parameters.theta;     % Recall that we allow the borrowing constraint to be age dependent
kappa=Parameters.kappa;
cost=Parameters.cost;
beta=Parameters.beta;
s=Parameters.s;
J=Parameters.J;
nTypes=Parameters.nTypes;

SS=vec2SS(guess,ExogPrices); % Given c and h, financial savings and bequests are determined in vec2SS function.

c=SS.c;
h=SS.h;
lambda=SS.lambda;
gamma=SS.gamma;
p=SS.p;
a=SS.a; 
b=SS.b; 

cfoc=zeros(J,nTypes);
hfoc=zeros(J,nTypes);
afoc=zeros(J,nTypes);
kuhn_tucker_error=zeros(J,nTypes);


for i=1:nTypes
    for j=1:J
        kt_error=abs(gamma(j,i)*(a(j,i)+theta(j)*p*h(j,i)));
        if (a(j,i)+theta(j)*p*h(j,i)<0) % borrowing constraint violated
            kt_error=kt_error-(a(j,i)+theta(j)*p*h(j,i));
        end;
        if(gamma(j,i)<0) %kuhn-tucker multiplier must be nonnegative
            kt_error=kt_error-gamma(j,i);
         end;
        kuhn_tucker_error(j,i)=kt_error;
    end;
end;


[Uc Uh]=Ces_derivatives(c,h,s(1:J,:));

for i=1:nTypes
    for j=1:J
        cfoc(j,i)=beta^(j-1)*Uc(j,i)-lambda(j,i);
        if(j<J)
            hfoc(j,i)=beta^(j-1)*Uh(j,i)-lambda(j,i)*(p+kappa*p+cost)+lambda(j+1,i)*p+gamma(j,i)*theta(j)*p;
            afoc(j,i)=-lambda(j,i)+lambda(j+1,i)*R+gamma(j,i);
        else
            hfoc(j,i)=beta^(j-1)*Uh(j,i)+beta^j*p*dutilbequest(b(i),s(j+1,i))-lambda(j,i)*(p+kappa*p+cost)+gamma(j,i)*theta(j)*p;
            afoc(j,i)=beta^j*R*dutilbequest(b(i),s(j+1,i))-lambda(j,i)+gamma(j,i);
        end;
        
        if(c(j,i)<1e-2)
            cfoc(j,i)=1e5+(1e-2-c(j,i));
        end;
        if(h(j,i)<1e-2)
            hfoc(j,i)=1e5+(1e-2-h(j,i));
        end;
    end;
end;


masses=Parameters.masses;
if(Parameters.fixed_house_stock==0)
    h_error=p-1;
else
    h_error=sum(h*masses)-Parameters.house_stock;
end;


aux1=vertcat(cfoc,hfoc,afoc,kuhn_tucker_error);
aux2=reshape(aux1,numel(aux1),1); % this is a vector containing first all errors for type 1, then all errors for type 2 etc.
z=[aux2;h_error];


