function z=Errors4Transition(x,Init_dist,ExogPrices,Final_SS)
global Parameters 
%Equilibrium conditions

J=Parameters.J;
nTypes=Parameters.nTypes;
s=Parameters.s;
R=ExogPrices.R;
beta=Parameters.beta;
kappa=Parameters.kappa;
cost=Parameters.cost;
theta=Parameters.theta;
T=Parameters.T;

Tr=vec2Transition(x,Init_dist,ExogPrices,Final_SS); 
C=Tr.C;
H=Tr.H;
LAMBDA=Tr.LAMBDA;
GAMMA=Tr.GAMMA; 
p=Tr.p;
A=Tr.A;
b=Tr.b;

pp=[p;Final_SS.p];

CFOC=zeros(J,T,nTypes);
HFOC=zeros(J,T,nTypes);
AFOC=zeros(J,T,nTypes);
KTFOC=zeros(J,T,nTypes);    % kuhn-tucker conditions
p_error=zeros(T,1);

for i=1:nTypes
    for t=1:T
        for j=1:J
            kt_error=abs(GAMMA(j,t,i)*(A(j,t,i)+theta(j)*pp(t)*H(j,t,i)));
            if (A(j,t,i)+theta(j)*pp(t)*H(j,t,i)<0)
                kt_error=kt_error-(A(j,t,i)+theta(j)*pp(t)*H(j,t,i));
            end
            if(GAMMA(j,t,i)<0)
                kt_error=kt_error-GAMMA(j,t,i);
            end
            KTFOC(j,t,i)=kt_error;
        end;
    end;
end;


[Uc Uh]=Ces_derivatives(C,H,s);

for i=1:nTypes
    for t=1:T
        for j=1:J
            
            CFOC(j,t,i)=beta^(j-1)*Uc(j,t,i)-LAMBDA(j,t,i);
            if(j==J)
                HFOC(j,t,i)=beta^(j-1)*Uh(j,t,i)+beta^j*pp(t+1)*dutilbequest(b(t+1,i),s(j+1,i))-LAMBDA(j,t,i)*(p(t)+kappa*p(t)+cost)+GAMMA(j,t,i)*theta(j)*pp(t);
                AFOC(j,t,i)=beta^j*R(t)*dutilbequest(b(t+1,i),s(j+1,i))-LAMBDA(j,t,i)+GAMMA(j,t,i);
            elseif(t==T)
                HFOC(j,t,i)=beta^(j-1)*Uh(j,t,i)-LAMBDA(j,t,i)*(p(t)+kappa*p(t)+cost)+Final_SS.lambda(j+1,i)*pp(t+1)+GAMMA(j,t,i)*theta(j)*pp(t);
                AFOC(j,t,i)=-LAMBDA(j,t,i)+Final_SS.lambda(j+1,i)*R(t)+GAMMA(j,t,i);
            else
                HFOC(j,t,i)=beta^(j-1)*Uh(j,t,i)-LAMBDA(j,t,i)*(p(t)+kappa*p(t)+cost)+LAMBDA(j+1,t+1,i)*pp(t+1)+GAMMA(j,t,i)*theta(j)*pp(t);
                AFOC(j,t,i)=-LAMBDA(j,t,i)+LAMBDA(j+1,t+1,i)*R(t)+GAMMA(j,t,i);
            end
            if(H(j,t,i)<0)
                HFOC(j,t,i)=1e5-H(j,t,i);
            end;
            if(C(j,t,i)<0)
                CFOC(j,t,i)=1e5-C(j,t,i);
            end;
        end
    end;
end;

%Housing demand and supply
HH=H;
for i=1:nTypes
    HH(:,:,i)=HH(:,:,i)*Parameters.masses(i);
end;

Aggregate_demand=sum(sum(HH,1),3);   % sum first over j(=age), then over i(=type);

if(Parameters.fixed_house_stock==1)
    p_error(1:T)=Aggregate_demand-Parameters.house_stock;
else
    p_error=p-1;
end;

if(Parameters.partial_eq==1)
    p_error=p-Parameters.p_partial_eq;
end;

Tr_focs.C=CFOC;
Tr_focs.H=HFOC;
Tr_focs.LAMBDA=AFOC;
Tr_focs.GAMMA=KTFOC;
Tr_focs.p=p_error;
z=Transition2vec(Tr_focs);

