function z=SolveTransition(Init_distr,ExogPrices)
global Parameters
%Solve the transition starting from an initial distribution (a and h) and
%for a given sequence of wage and interest rates. Wage and interest rates are assumed to
%converge to their final ss levels

J=Parameters.J;
T=Parameters.T;
nTypes=Parameters.nTypes;
n=length(ExogPrices.wages);

ExogSSPrices.wage=ExogPrices.wages(n);
ExogSSPrices.R=ExogPrices.R(n);

Final_SS=SolveSS(ExogSSPrices);

% guess for c, h, multipliers, and house prices
Tr.C=zeros(J,T,nTypes);
Tr.H=zeros(J,T,nTypes);
Tr.LAMBDA=zeros(J,T,nTypes);
Tr.GAMMA=zeros(J,T,nTypes);


for i=1:nTypes;
    for age=1:J
        for t=1:T
            Tr.C(age,t,i)=Final_SS.c(age,i);
            Tr.H(age,t,i)=Final_SS.h(age,i);
            Tr.LAMBDA(age,t,i)=Final_SS.lambda(age,i);
            Tr.GAMMA(age,t,i)=Final_SS.gamma(age,i);
        end;
    end;
end;
Tr.p=Final_SS.p*ones(T,1); 

% it helps to start with lower consumption than in the final SS 
if ExogPrices.wages(1)<=1
Tr.C(:,1:2,:)=0.8*Tr.C(:,1:2,:);  
Tr.H(:,1:2,:)=0.8*Tr.H(:,1:2,:); 
end

% transform the guess into a vector 
guess=Transition2vec(Tr);
[x,errors] = fsolve('Errors4Transition',guess,Parameters.opts,Init_distr,ExogPrices,Final_SS);
max_error_tr=max(abs(errors));
if(max_error_tr<Parameters.tol)
    disp('Transition solved accurately')
else
    disp('Transition NOT solved accurately')
end;

z=vec2Transition(x,Init_distr,ExogPrices,Final_SS);
