function R=dynamics(figure)   
global Parameters

%Set age profiles for income and hh size
Parameters.nTypes=5;    % number of different household types
SetProfiles

% Set some other parameter values
Parameters.kappa=0.02;  % housing cost proportional to the value of the house
Parameters.cost=0.08;   % housing cost proportional to the size of the house
Parameters.R=1.08;      % interest rate
Parameters.rho=-1;      % CES parameter
Parameters.sigma=2.0;   %inverse ov intertemporal elasticity
Parameters.tol=1e-3;
Parameters.opts=optimset('TolFun',Parameters.tol,'Display','Off');
Parameters.partial_eq=0;

if figure==6
%% positive and negative and temporary and permanent income shocks,with and without BC 

% Benchmark calibration targets:
Parameters.mean_NWHV=0.82;% Mean net-wealth-to-house-value
Parameters.mean_NWHV_J=1.05;% Mean net-wealth-to-house-value at age J
Parameters.mean_NWI=0.86;% Mean net-wealth-to-income ratio

%first calibrate with BC
ExogSSPrices.R=Parameters.R;
ExogSSPrices.wage=1;
Parameters.theta=10.75*ones(Parameters.J,1);%down payment parameter, may vary with age 
SS_bc=calibrate(ExogSSPrices);
R.SS=SS_bc;
R.Parameters=Parameters;

Init_distr.a=SS_bc.a;
Init_distr.h=SS_bc.h;

%Specify the various shocks;
T=Parameters.T;

ExogPrices.wages=ones(T+1,1);
ExogPrices.R=Parameters.R*ones(T+1,1);

ExogPrices1=ExogPrices;
ExogPrices2=ExogPrices;
ExogPrices3=ExogPrices;
ExogPrices4=ExogPrices;

x=1.0574;
 for t=1:4
     ExogPrices1.wages(t)=0.8*x^(t-1);
 end

ExogPrices2.wages=0.9*ones(T+1,1);

x=0.9554;
for t=1:4
    ExogPrices3.wages(t)=1.2*x^(t-1);
end

ExogPrices4.wages=1.1*ones(T+1,1);

%Solve for all 4 transitions with BC
Tr_bc_1=SolveTransition(Init_distr,ExogPrices1);
Tr_bc_2=SolveTransition(Init_distr,ExogPrices2);
Tr_bc_3=SolveTransition(Init_distr,ExogPrices3);
Tr_bc_4=SolveTransition(Init_distr,ExogPrices4);

%recalibrate without BC
Parameters.theta=10*ones(Parameters.J,1); %Can borrow up to 10 times the value of the house. This will never be binding.
SS_no_bc=calibrate(ExogSSPrices);
Init_distr.a=SS_no_bc.a;%the initial distribution is different
Init_distr.h=SS_no_bc.h;

%Solve for all 4 transitions without BC
Tr_no_bc_1=SolveTransition(Init_distr,ExogPrices1);
Tr_no_bc_2=SolveTransition(Init_distr,ExogPrices2);
Tr_no_bc_3=SolveTransition(Init_distr,ExogPrices3);
Tr_no_bc_4=SolveTransition(Init_distr,ExogPrices4);

%finally, plot all prices
hold off
subplot(2,2,1),plot(Tr_bc_1.p,'-xb')
hold on
subplot(2,2,1),plot(Tr_no_bc_1.p,'-or')
subplot(2,2,2),plot(Tr_bc_2.p,'-xb')
hold on
subplot(2,2,2),plot(Tr_no_bc_2.p,'-or')
subplot(2,2,3),plot(Tr_bc_3.p,'-xb')
hold on
subplot(2,2,3),plot(Tr_no_bc_3.p,'-or')
subplot(2,2,4),plot(Tr_bc_4.p,'-xb')
hold on
subplot(2,2,4),plot(Tr_no_bc_4.p,'-or')

end

if figure==7
%% positive and negative and temporary and permanent interest rate shocks,with and without BC 
% Benchmark calibration targets:
Parameters.mean_NWHV=0.82;% Mean net-wealth-to-house-value
Parameters.mean_NWHV_J=1.05;% Mean net-wealth-to-house-value at age J
Parameters.mean_NWI=0.86;% Mean net-wealth-to-income ratio

%first calibrate with BC
ExogSSPrices.R=Parameters.R;
ExogSSPrices.wage=1;
J=Parameters.J;
Parameters.theta=0.75*ones(Parameters.J,1);
SS=calibrate(ExogSSPrices);
Init_distr.a=SS.a;
Init_distr.h=SS.h;

% %Specify the various shocks;
 T=Parameters.T;
 ExogPrices.wages=ones(T+1,1);
 ExogPrices.R=Parameters.R*ones(T+1,1);
% 
 ExogPrices1=ExogPrices;
 ExogPrices2=ExogPrices;
 ExogPrices3=ExogPrices;
 ExogPrices4=ExogPrices;
% 
 ExogPrices1.R(1:2)=1.16;
 ExogPrices2.R=1.1*ones(T+1,1);
 ExogPrices3.R(1:2)=1.0;
 ExogPrices4.R=1.06*ones(T+1,1);
% 
% %Solve for all 4 transitions with BC
Tr_bc_1=SolveTransition(Init_distr,ExogPrices1);
Tr_bc_2=SolveTransition(Init_distr,ExogPrices2);
Tr_bc_3=SolveTransition(Init_distr,ExogPrices3);
Tr_bc_4=SolveTransition(Init_distr,ExogPrices4);

%recalibrate without BC
Parameters.theta=10*ones(J,1);
SS=calibrate(ExogSSPrices);
Init_distr.a=SS.a;
Init_distr.h=SS.h;

%Solve for all 4 transitions without BC
Tr_no_bc_1=SolveTransition(Init_distr,ExogPrices1);
Tr_no_bc_2=SolveTransition(Init_distr,ExogPrices2);
Tr_no_bc_3=SolveTransition(Init_distr,ExogPrices3);
Tr_no_bc_4=SolveTransition(Init_distr,ExogPrices4);

%finally, plot all prices
hold off
subplot(2,2,1),plot(Tr_bc_1.p,'-xb')
hold on
subplot(2,2,1),plot(Tr_no_bc_1.p,'-or')

subplot(2,2,2),plot(Tr_bc_2.p,'-xb')
hold on
subplot(2,2,2),plot(Tr_no_bc_2.p,'-or')

subplot(2,2,3),plot(Tr_bc_3.p,'-xb')
hold on
subplot(2,2,3),plot(Tr_no_bc_3.p,'-or')

subplot(2,2,4),plot(Tr_bc_4.p,'-xb')
hold on
subplot(2,2,4),plot(Tr_no_bc_4.p,'-or')

end

if figure==8
%% negative income shock, benchmark vs. more leveraged hhs,with and without BC 

% Benchmark calibration targets:
Parameters.mean_NWHV=0.82;% Mean net-wealth-to-house-value
Parameters.mean_NWHV_J=1.05;% Mean net-wealth-to-house-value at age J
Parameters.mean_NWI=0.86;% Mean net-wealth-to-income ratio

%Specify the shocks;
T=Parameters.T;
ExogPrices.wages=ones(T+1,1);
ExogPrices.R=Parameters.R*ones(T+1,1);

x=1.0574;
 for t=1:4
     ExogPrices.wages(t)=0.8*x^(t-1);
 end

%benchmark calibration with BC
ExogSSPrices.R=Parameters.R;
ExogSSPrices.wage=1;
Parameters.theta=0.75*ones(Parameters.J,1);
SS=calibrate(ExogSSPrices);
Init_distr.a=SS.a;
Init_distr.h=SS.h;

%Solve for 1. transition
Tr_bc=SolveTransition(Init_distr,ExogPrices);


%benchmark calibration without BC
Parameters.theta=10*ones(Parameters.J,1);
SS=calibrate(ExogSSPrices);
Init_distr.a=SS.a;
Init_distr.h=SS.h;

%Solve for 2. transition
Tr_no_bc=SolveTransition(Init_distr,ExogPrices);

%highly leveraged case with BC
Parameters.theta=0.75*ones(Parameters.J,1);
Parameters.mean_NWHV=0.63;
Parameters.mean_NWHV_J=1.02;
Parameters.mean_NWI=0.64;

SS=calibrate(ExogSSPrices);
Init_distr.a=SS.a;
Init_distr.h=SS.h;

%Solve for 3. transition
Tr_bc_leveraged=SolveTransition(Init_distr,ExogPrices);

%highly leveraged case without BC
Parameters.theta=10*ones(Parameters.J,1);
SS=calibrate(ExogSSPrices);
Init_distr.a=SS.a;
Init_distr.h=SS.h;

%Solve for 4. transition
Tr_no_bc_leveraged=SolveTransition(Init_distr,ExogPrices);

%finally, plot all prices
hold off
plot(Tr_bc.p,'-xb')
hold on
plot(Tr_bc_leveraged.p,'-.xb')
plot(Tr_no_bc.p,'-or')
plot(Tr_no_bc_leveraged.p,'-.or')
legend('constr.','constr. more leverage','no constr.','no constr. more leverage')
end


if figure==9
% Partial equilibrium exercise: lower period 1 house price by 1% starting from the equilibrium price seq. associated with
% negative temporary income shock.

% Benchmark calibration targets:
Parameters.mean_NWHV=0.82;% Mean net-wealth-to-house-value
Parameters.mean_NWHV_J=1.05;% Mean net-wealth-to-house-value at age J
Parameters.mean_NWI=0.86;% Mean net-wealth-to-income ratio

%calibrate
ExogSSPrices.R=Parameters.R;
ExogSSPrices.wage=1;
Parameters.theta=0.75*ones(Parameters.J,1);%down payment parameter, may vary with age
SS_bc=calibrate(ExogSSPrices);
Init_distr.a=SS_bc.a;
Init_distr.h=SS_bc.h;

%Specify the shock;
T=Parameters.T;
ExogPrices.wages=ones(T+1,1);
ExogPrices.R=Parameters.R*ones(T+1,1);

 x=1.0574;
 for t=1:4
     ExogPrices.wages(t)=0.8*x^(t-1);
 end
 
 Tr=SolveTransition(Init_distr,ExogPrices);
 Parameters.partial_eq=1;
 Parameters.p_partial_eq=Tr.p;
 Parameters.p_partial_eq(1)=0.99*Tr.p(1);
 Tr_part_eq=SolveTransition(Init_distr,ExogPrices);

 Analyze_partial_eq(Tr_part_eq,Tr); %draws the picture

end
