function dynamics_multiple_shocks
global Parameters
%Creates figure 5

% Set parameter values
SetProfiles;

Parameters.kappa=0.02;  % housing cost proportional to the value of the house
Parameters.cost=0.08;   % housing cost proportional to the size of the house
Parameters.tol=1e-3;
Parameters.opts=optimset('TolFun',Parameters.tol,'Display','Off');
Parameters.partial_eq=0;
Parameters.theta=0.75*ones(Parameters.J,1);    % theta = the share of value of the house that can be borrowed. Note that in the paper theta is the share to be financed by savings!
Parameters.sigma=2.0;               % sigma = the inverse of intertemporal elasticity of substitution

%calibration targets
Parameters.mean_NWHV=0.82;
Parameters.mean_NWHV_J=1.05;
Parameters.mean_NWI=0.86;

Price_sequences=cell(3,1);

for rho_case=1:3
    
    if rho_case==1
        Parameters.rho=-2;                  % rho = CES-parameter
    elseif rho_case==2
        Parameters.rho=-1;
    elseif rho_case==3
        Parameters.rho=0;
    end
    
    Parameters.theta=0.75*ones(Parameters.J,1);
    ExogSSPrices.wage=1;
    ExogSSPrices.R=1.08;
    
    %%calibrate endogenous parameters
    SS=calibrate(ExogSSPrices);
    
    
    %% Solve for transition with different shocks
    
    Transitions=cell(5,1);
    for k=1:5;
        
        if (k==1)
            Parameters.theta=0.20*ones(Parameters.J,1);%initial steady state with a tight borrowing constraint
            SS0=SolveSS(ExogSSPrices);
            Init_dist.a=SS0.a;%the initial distribution is the one associated with the ss. with a tight borrowing constraint
            Init_dist.h=SS0.h;
            
            Parameters.theta=0.75*ones(Parameters.J,1);%the first "shock" is the relaxation of the borrowing constraint
            ExogPrices.wages=ones(Parameters.T+1,1);
            ExogPrices.R=1.08*ones(Parameters.T+1,1);
        else
            Init_dist.a=Tr.A(:,1,:);
            Init_dist.h=Tr.H(:,1,:);
            
            if (k==2)
                ExogPrices.wages=(1-0.051)*ones(Parameters.T+1,1);%the first income shock...
            end
            if (k==3)
                ExogPrices.wages=(1-0.089)*ones(Parameters.T+1,1);                
            end
            if (k==4)
                ExogPrices.wages=(1-0.045)*ones(Parameters.T+1,1);               
            end
            if (k==5)
                ExogPrices.wages=(1-0.0)*ones(Parameters.T+1,1);                
            end
            
        end;
        
        str=['Now solving for Transition number ', num2str(k),' rho case ',num2str(rho_case)];
        disp(str)
        Tr=SolveTransition(Init_dist,ExogPrices);
        Transitions{k}=Tr;
        
    end;
    
    pseq=zeros(15,1);
    pseq(1)=SS0.p;
    for i=1:4
        pseq(i+1)=Transitions{i}.p(1);
    end
    pseq(6:15)=Transitions{5}.p(1:10);
    
    Price_sequences{rho_case}=pseq;
    
    if rho_case==2
        Price_sequence_relaxation=[SS0.p Transitions{1}.p'];
    end;
    
end


plot(Price_sequences{1},'ro-')
hold on
plot(Price_sequences{2},'*-')
plot(Price_sequences{3},'kv-')
plot(Price_sequence_relaxation,'*--')
legend('rho=-2','rho=-1','rho=0','relaxation alone')

