function z=vec2SS(v,ExogSSPrices);
global Parameters;

kappa=Parameters.kappa;
cost=Parameters.cost;
R=ExogSSPrices.R;
wage=ExogSSPrices.wage;
y=Parameters.y;
masses=Parameters.masses;  


nTypes=Parameters.nTypes;
J=Parameters.J;

L=length(v);
aux=reshape(v(1:L-1),(L-1)/nTypes,nTypes);
z.c=aux(1:J,:);
z.h=aux(J+1:2*J,:);
z.lambda=aux(2*J+1:3*J,:);
z.gamma=aux(3*J+1:4*J,:);
z.p=v(L);

c=z.c;
h=z.h;
p=z.p;

% Determine a (financial savings for each period and household type) and b (terminal wealth for each household type)
a=zeros(J,nTypes);
b=ones(nTypes,1);


for i=1:nTypes;
    a(1,i)=wage*y(1)-c(1,i)-(p+kappa*p+cost)*h(1,i); % In period 1, there are no initial assets.
    for j=2:J
        a(j,i)=wage*y(j)-c(j,i)-(p+kappa*p+cost)*h(j,i)+R*a(j-1,i)+p*h(j-1,i);
    end;
end;

for i=1:nTypes
    b(i)=R*a(J,i)+p*h(J,i);
end;

z.a=a;
z.b=b;

% Finally, we compute leverage ratios and other statistics

NW=ones(J,nTypes);   % net worth
NWHV=ones(J,nTypes); % net worth-to-house value
NWI=ones(J,nTypes);  % net worth-to-income

for i=1:nTypes
    for j=1:J
        NW(j,i)=a(j,i)+p*h(j,i);
        NWHV(j,i)=(a(j,i)+p*h(j,i))/(p*h(j,i));
        NWI(j,i)=(a(j,i)+p*h(j,i))/(wage*y(j));
    end;
end;

m=zeros(4,1); % We classify the households according to their NWHV. m collects the mass in each segment. 

M=0;
M1=0;
mean_NWs=zeros(J,1);
mean_NWHVs=zeros(J,1);
mean_NWIs=zeros(J,1);

mean_NW_J=0;
mean_NWI_J=0;

Mortgage=0;
TotalC=0;

for i=1:nTypes
    for j=1:J
        M=M+masses(i);
        mean_NWs(j)=mean_NWs(j)+masses(i)*NW(j,i);
        mean_NWHVs(j)=mean_NWHVs(j)+masses(i)*NWHV(j,i);
        mean_NWIs(j)=mean_NWIs(j)+masses(i)*NWI(j,i);
        TotalC=TotalC+masses(i)*c(j,i);
        if(a(j,i)<0)
            Mortgage=Mortgage-masses(i)*a(j,i);
        end;
        if(j==J)
            mean_NW_J=mean_NWs(j)+masses(i)*NW(j,i);
            mean_NWHV_J=mean_NWHVs(j)+masses(i)*NWHV(j,i);
            mean_NWI_J=mean_NWIs(j)+masses(i)*NWI(j,i);
        end;
        if(NWHV(j,i)>=1.0)
            m(4)=m(4)+masses(i);
        elseif(NWHV(j,i)>=0.5)
            m(3)=m(3)+masses(i);
        elseif(NWHV(j,i)>=0.25-1e-5)
            m(2)=m(2)+masses(i);
        else
            m(1)=m(1)+masses(i);
        end;
    end;
end;

z.NWHV_distr=m/sum(m);
z.mean_NW=sum(mean_NWs)/J;
z.mean_NWHV=sum(mean_NWHVs)/J;
z.mean_NWI=sum(mean_NWIs)/J;
z.mean_NWs=mean_NWs;
z.mean_NW_J=mean_NW_J;
z.mean_NWHVs=mean_NWHVs;
z.mean_NWHV_J=mean_NWHV_J;
z.mean_NWIs=mean_NWIs;
z.mean_NWI_J=mean_NWI_J;

z.NWHV=NWHV;
z.NWI=NWI;
z.masses=Parameters.masses;
z.Hsum=sum(h*masses);
z.M=M;
z.Mortgage=Mortgage;
z.TotalC=TotalC;

